package
Version:
v0.0.0-...-0f0f5c3
Opens a new window with list of versions in this module.
Published: Jan 19, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Location represents a location in a source file
FindDefinition finds the definition of a symbol at the given position
type Position struct {
Line int
Character int
}
Position represents a position in a document (0-based line and character)
Range represents a range in a document
Source Files
¶
Click to show internal directories.
Click to hide internal directories.